@@ -1,5 +1,5 @@
 package WebService::Raygun::Message::Error;
-$WebService::Raygun::Message::Error::VERSION = '0.024';
+$WebService::Raygun::Message::Error::VERSION = '0.026';
 use Mouse;
 
 =head1 NAME
@@ -12,7 +12,22 @@ WebService::Raygun::Message::Error - Encapsulate the error part of the raygion.i
 
 =head1 DESCRIPTION
 
-You shouldn't need to instantiate this class directly.
+You shouldn't need to instantiate this class directly as L<WebService::Raygun::Message|WebService::Raygun::Message> will automatically coerce a number of different object types into this by default. At the moment the following types are supported:
+
+=over 2
+
+
+=item L<Devel::StackTrace|Devel::StackTrace>
+
+=item L<Moose::Exception|Moose::Exception>
+
+=item L<Mojo::Exception|Mojo::Exception>
+
+=back
+
+
+I may add more in the future.
+
 
 =head1 INTERFACE
 
@@ -125,11 +140,6 @@ coerce 'MessageError' => from 'HashRef' => via {
 
 no Mouse::Util::TypeConstraints;
 
-=head2 _parse_exception_line
-
-Parse a text line into bits for a typical error.
-
-=cut
 
 sub _parse_exception_line {
     my ($self, $error_text) = @_;
@@ -160,6 +170,19 @@ has inner_error => (
     },
 );
 
+=head2 data
+
+=over 2
+
+=item *
+C<HASHREF> 
+
+Data for debugging the error.
+
+=back
+
+=cut
+
 has data => (
     is      => 'rw',
     isa     => 'HashRef',
@@ -168,6 +191,13 @@ has data => (
     },
 );
 
+
+=head2  class_name
+
+The name of the error.
+
+=cut
+
 has class_name => (
     is      => 'rw',
     isa     => 'Str',
@@ -176,6 +206,13 @@ has class_name => (
     },
 );
 
+=head2 message
+
+An error message.
+
+
+=cut
+
 has message => (
     is      => 'rw',
     isa     => 'Str',
@@ -184,6 +221,12 @@ has message => (
     },
 );
 
+=head2 stack_trace
+
+An array of stack traces.
+
+=cut
+
 has stack_trace => (
     is      => 'rw',
     isa     => 'ArrayOfStackTraces',
@@ -191,8 +234,6 @@ has stack_trace => (
     default => sub {
         return [];
     },
-
-    # other attributes
 );
 
 =head2 prepare_raygun
@@ -211,12 +252,6 @@ sub prepare_raygun {
         stackTrace => [ map { $_->prepare_raygun } @{ $self->stack_trace } ] };
 }
 
-=head2 _iterate_stack_trace_frames
-
-Iterate over frames in a L<Devel::StackTrace|Devel::StackTrace> like object.
-
-=cut
-
 sub _iterate_stack_trace_frames {
     my ($self, $trace) = @_;
     my $stack_trace = [];
@@ -232,13 +267,8 @@ sub _iterate_stack_trace_frames {
     return $stack_trace;
 }
 
-=head1 DEPENDENCIES
 
 
-=head1 SEE ALSO
-
-=cut
-
 1;
 
 __END__
