@@ -1,7 +1,8 @@
 package WebService::Raygun::Message::Request;
-$WebService::Raygun::Message::Request::VERSION = '0.024';
+$WebService::Raygun::Message::Request::VERSION = '0.026';
 use Mouse;
-use Mouse::Util::TypeConstraints;
+use WebService::Raygun::Message::Request::QueryString;
+
 
 =head1 NAME
 
@@ -22,6 +23,7 @@ WebService::Raygun::Message::Request - Encapsulate the data in a typical HTTP re
 
 =cut
 
+use Mouse::Util::TypeConstraints;
 subtype 'RawData' => as 'Str';    # => where {};
 
 subtype 'Request' => as 'Object' => where {
@@ -49,13 +51,14 @@ coerce 'Request' => from 'HttpRequest' => via {
     }
     my $query_string = $_->uri->query || '';
 
-    return WebService::Raygun::Message::Request->new(
+    my $ws = WebService::Raygun::Message::Request->new(
         url          => $_->uri->as_string,
         raw_data     => $_->as_string,
         headers      => $headers,
         http_method  => $_->method,
         query_string => $query_string,
     );
+    return $ws;
 } => from 'MojoliciousRequest' => via {
     my $headers      = $_->headers->to_hash;
     my $query_params = $_->query_params;
@@ -63,13 +66,14 @@ coerce 'Request' => from 'HttpRequest' => via {
     if (defined $query_params and $query_params->isa('Mojo::Parameters')) {
         $query_string = $query_params->to_string;
     }
-    return WebService::Raygun::Message::Request->new(
+    my $ws = WebService::Raygun::Message::Request->new(
         url          => $_->url->to_abs->path,
         http_method  => $_->method,
         raw_data     => $_->get_body_chunk,
         headers      => $headers,
-        query_string => $query_string
+        query_string => $query_string,
     );
+    return $ws;
 } => from 'CatalystRequest' => via {
 
     my @header_names = $_->headers->header_field_names;
@@ -81,7 +85,7 @@ coerce 'Request' => from 'HttpRequest' => via {
     my $chunk;
     $_->read_chunk(\$chunk, 4096);
     my $query_string = $_->uri->query || '';
-    return WebService::Raygun::Message::Request->new(
+    my $ws = WebService::Raygun::Message::Request->new(
         ip_address   => $_->address,
         headers      => $headers,
         http_method  => $_->method,
@@ -89,6 +93,7 @@ coerce 'Request' => from 'HttpRequest' => via {
         raw_data     => $chunk,
         query_string => $query_string,
     );
+    return $ws;
 } => from 'HashRef' => via {
     return WebService::Raygun::Message::Request->new(%{$_});
 };
@@ -100,6 +105,8 @@ coerce 'RawData' => from 'Str' => via {
     return $truncated;
 };
 
+no Mouse::Util::TypeConstraints;
+
 has host_name => (
     is  => 'rw',
     isa => 'Str',
@@ -128,9 +135,10 @@ has ip_address => (
 
 has query_string => (
     is      => 'rw',
-    isa     => 'Str',
+    isa     => 'RaygunQueryString',
+    coerce => 1,
     default => sub {
-        return '';
+        return {};
     }
 );
 
@@ -161,7 +169,7 @@ sub prepare_raygun {
         hostName    => $self->host_name,
         url         => $self->url,
         httpMethod  => $self->http_method,
-        queryString => $self->query_string,
+        queryString => $self->query_string->prepare_raygun,
         headers     => $self->headers,
         rawData     => $self->raw_data,
     };
